@@ -5,11 +5,17 @@ context("Testing ddelap")
 test_that("Singleton ddelap functions", {
   expect_equal(ddelap(SEQUENCE, 1, 4, 2), VAL$DDELAP_1)
   expect_equal(ddelap(SEQUENCE, 5, 3, 8, log = TRUE), log(ddelap(SEQUENCE, 5, 3, 8)))
+  expect_true(is.nan(ddelap(1, 0, 1, 2)))
+  expect_true(is.nan(ddelap(0, 1, 0, 2)))
+  expect_true(is.nan(ddelap(0, 1, 4, 0)))
 })
+
 test_that("Vector ddelap functions", {
   expect_equal(ddelap(SEQUENCE, c(1, 2, 3), c(4, 1, 2), c(2, 5, 7)), VAL$DDELAP_Triple)
   expect_equal(ddelap(seq_len(101) - 1, c(4, 9, 2), c(6, 12, 8), c(7, 14, 9), log = TRUE), 
               log(ddelap(seq_len(101) - 1, c(4, 9, 2), c(6, 12, 8), c(7, 14, 9))))
+  expect_identical(is.nan(ddelap(seq_len(10), 0, 1, 2)), rep(TRUE, 10))
+  expect_identical(is.nan(ddelap(seq_len(3), c(0, 1, 2), c(1, 0, 2), c(1, 2, 0))), rep(TRUE, 3))
 })
   
 context("Testing pdelap")
@@ -18,12 +24,18 @@ test_that("Singleton pdelap functions", {
   expect_equal(pdelap(SEQUENCE, 4, 5, 1, log.p = TRUE), log(pdelap(SEQUENCE, 4, 5, 1)))
   expect_equal(pdelap(seq_len(101) - 1, 8, 10, 6, lower.tail = FALSE), 1 - pdelap(seq_len(101) - 1, 8, 10, 6))
   expect_equal(pdelap(6, 2.9647, 0.005/2.9647, 0.0057, lower.tail=FALSE), 0)
+  expect_true(is.nan(pdelap(1, 0, 1, 2)))
+  expect_true(is.nan(pdelap(0, 1, 0, 2)))
+  expect_true(is.nan(pdelap(0, 1, 4, 0)))
+  
 })
 
 test_that("Vector pdelap functions", {
   expect_equal(pdelap(SEQUENCE, c(1, 2, 3), c(4, 1, 2), c(2, 5, 7)), VAL$PDELAP_Triple)
   expect_equal(pdelap(seq_len(101) - 1, c(4, 9, 2), c(6, 12, 8), c(7, 14, 9), lower.tail = FALSE),
               1 - pdelap(seq_len(101) - 1, c(4, 9, 2), c(6, 12, 8), c(7, 14, 9)))
+  expect_identical(is.nan(pdelap(seq_len(10), 0, 1, 2)), rep(TRUE, 10))
+  expect_identical(is.nan(pdelap(seq_len(3), c(0, 1, 2), c(1, 0, 2), c(1, 2, 0))), rep(TRUE, 3))
 })
 
 context("Testing qdelap")
@@ -31,10 +43,16 @@ test_that("Singleton qdelap functions", {
   expect_equal(qdelap(.4, 1, 4, 2), 4)
   expect_equal(qdelap(0.4971031395336245, 4, 6, 3, lower.tail = TRUE), 25)
   expect_equal(qdelap(-0.255, 20, 15, 50, log.p = TRUE), 400)
+  expect_true(is.nan(qdelap(.05, 0, 1, 2)))
+  expect_true(is.nan(qdelap(0, 1, 0, 2)))
+  expect_true(is.nan(qdelap(1, 1, 4, 0)))
 })
+
 test_that("Vector qdelap functions", {
   expect_equal(qdelap(c(.4, .07), c(1, 2), c(4, 1), c(2, 5)), c(4, 3))
   expect_equal(qdelap(c(0.4971031395336245, 0.1374992163369109), c(4, 1), c(6, 9), c(3, 12), lower.tail = FALSE), c(25, 31))
+  expect_identical(is.nan(pdelap(seq_len(2)/10, 0, 1, 2)), rep(TRUE, 2))
+  expect_identical(is.nan(pdelap(seq_len(3)/10, c(0, 1, 2), c(1, 0, 2), c(1, 2, 0))), rep(TRUE, 3))
 })
 
 context("Testing rdelap")
@@ -43,12 +61,19 @@ test_that("Singleton rdelap functions", {
   DP2 <- rdelap(1e6, alpha = 2, beta = 14, lambda = 2, exact = FALSE)
   expect_that(abs((mean(DP1) / 30 - 1)) < 5e-3, is_true())
   expect_that(abs((mean(DP2) / 30 - 1)) < 5e-3, is_true())
+  expect_true(is.nan(rdelap(1, 0, 1, 2)))
+  expect_true(is.nan(rdelap(1, 1, 0, 2)))
+  expect_true(is.nan(rdelap(1, 1, 4, 0)))
 })
+
 test_that("Vector rdelap functions", {
   DP3 <- rdelap(1e3, alpha = c(5, 5), beta = c(5, 5), lambda = c(5, 5))
   DP4 <- rdelap(1e6, alpha = c(5, 5), beta = c(5, 5), lambda = c(5, 5), exact = FALSE)
   expect_that(abs((mean(DP3) / 30 - 1)) < 5e-2, is_true())
   expect_that(abs((mean(DP4) / 30 - 1)) < 5e-3, is_true())
+  expect_identical(is.nan(rdelap(2, 0, 1, 2)), rep(TRUE, 2))
+  expect_identical(is.nan(rdelap(3, c(0, 1, 2), c(1, 0, 2), c(1, 2, 0))), rep(TRUE, 3))
+  expect_equal(sum(is.nan(rdelap(3, c(0, 1, 2), c(1, 0, 2), c(1, 2, 1)))), 2)
 })
 
 context("Testing MoMdelap")
@@ -61,5 +86,5 @@ test_that("MoMdelap functions", {
 })
 test_that("MoMdelap traps bad parameters", {
   TestData <- c(3,  2, 12, 11,  1,  7,  1,  4,  0, 4)
-  expect_that(MoMdelap(TestData), throws_error("Method of moments not appropriate for this data; results include negative parameters."))
+  expect_that(MoMdelap(TestData), throws_error("Method of moments not appropriate for this data; results include non-positive parameters."))
 })
\ No newline at end of file
